@@ -4,6 +4,10 @@ from django.core.cache.backends.memcached import MemcachedCache, PyLibMCCache
 MAX_RETRIES = settings.get('CAS_CACHE_MAX_RETRIES', 10)
 
 
+class NoneValueError(Exception):
+    pass
+
+
 class CASMixin(object):
     def cas(self, key, update_func, timeout=0, version=None):
         key = self.make_key(key, version=version)
@@ -11,6 +15,9 @@ class CASMixin(object):
         while i < MAX_RETRIES:
             current_val = self._cache.gets(key)
             assert current_val is not None
+            new_val = update_func(current_val)
+            if new_val is None:
+                raise NoneValueError('Your update_func must not return None')
             result = self._cache.cas(key, update_func(current_val))
             if result:
                 break
